tangle_subxt0.7.0

Module api

Module Items

  • Modules
  • Structs
  • Statics
  • Functions
  • Type Aliases

In tangle_subxt::tangle_testnet_runtime

tangle_subxt::tangle_testnet_runtime

Module api

Modules

  • assets
  • authorship
  • babe
  • bags_list
  • balances
  • base_fee
  • bounties
  • child_bounties
  • claims
  • council
  • democracy
  • dynamic_fee
  • election_provider_multi_phase
  • elections
  • ethereum
  • evm
  • evm_chain_id
  • grandpa
  • historical
  • hotfix_sufficients
  • identity
  • im_online
  • indices
  • lst
  • multi_asset_delegation
  • multisig
  • nomination_pools
  • offences
  • preimage
  • proxy
  • randomness_collective_flip
  • runtime_apis
  • runtime_types
  • scheduler
  • services
  • session
  • staking
  • sudo
  • system
  • timestamp
  • transaction_payment
  • treasury
  • tx_pause
  • utility
  • vesting

Structs

  • ConstantsApi
  • CustomValuesApi
  • StorageApi
  • TransactionApi

Statics

  • PALLETS
  • RUNTIME_APIS

Functions

  • apis
  • constants
  • custom
  • is_codegen_valid_for
    check whether the metadata provided is aligned with this statically generated code.
  • storage
  • tx

Type Aliases

  • Call
    The outer extrinsic enum.
  • DispatchError
    The error type that is returned when there is a runtime issue.
  • Error
    The outer error enum represents the DispatchError’s Module variant.
  • Event
    The outer event enum.