tangle_subxt::tangle_testnet_runtime::api::proxy

Module events

Modules

Structs

  • An announcement was placed to make a call in the future.
  • A proxy was added.
  • A proxy was executed correctly, with the given.
  • A proxy was removed.
  • A pure account has been created by new proxy with given disambiguation index and proxy type.