tangle_subxt::tangle_testnet_runtime::api::services::calls

Struct TransactionApi

pub struct TransactionApi;

Implementations

Source

impl TransactionApi

pub fn create_blueprint( &self, blueprint: Blueprint, ) -> StaticPayload<CreateBlueprint>

Create a new service blueprint.

A Service Blueprint is a template for a service that can be instantiated later on by a user.

Parameters
  • origin: The account that is creating the service blueprint.
  • blueprint: The blueprint of the service.
pub fn pre_register( &self, blueprint_id: BlueprintId, ) -> StaticPayload<PreRegister>

Pre-register the caller as an operator for a specific blueprint.

The caller can pre-register for a blueprint, which will emit a PreRegistration event. This event can be listened to by the operator node to execute the custom blueprint’s registration function.

Parameters
  • origin: The account that is pre-registering for the service blueprint.
  • blueprint_id: The ID of the service blueprint.
pub fn register( &self, blueprint_id: BlueprintId, preferences: Preferences, registration_args: RegistrationArgs, value: Value, ) -> StaticPayload<Register>

Register the caller as an operator for a specific blueprint.

The caller may require an approval first before they can accept to provide the service for the users.

pub fn unregister(&self, blueprint_id: BlueprintId) -> StaticPayload<Unregister>

Unregister the caller from being an operator for the service blueprint so that, no more services will assigned to the caller for this specific blueprint. Note that, the caller needs to keep providing service for other active service that uses this blueprint, until the end of service time, otherwise they may get reported and slashed.

pub fn update_price_targets( &self, blueprint_id: BlueprintId, price_targets: PriceTargets, ) -> StaticPayload<UpdatePriceTargets>

Update the price targets for the caller for a specific service blueprint.

See Self::register for more information.

pub fn request( &self, blueprint_id: BlueprintId, permitted_callers: PermittedCallers, operators: Operators, request_args: RequestArgs, assets: Assets, ttl: Ttl, value: Value, ) -> StaticPayload<Request>

Request a new service to be initiated using the provided blueprint with a list of operators that will run your service. Optionally, you can specifiy who is permitted caller of this service, by default only the caller is allowed to call the service.

pub fn approve( &self, request_id: RequestId, restaking_percent: RestakingPercent, ) -> StaticPayload<Approve>

Approve a service request, so that the service can be initiated.

The restaking_percent is the percentage of the restaked tokens that will be exposed to the service.

pub fn reject(&self, request_id: RequestId) -> StaticPayload<Reject>

Reject a service request. The service will not be initiated, and the requester will need to update the service request.

pub fn terminate(&self, service_id: ServiceId) -> StaticPayload<Terminate>

Terminates the service by the owner of the service.

pub fn call( &self, service_id: ServiceId, job: Job, args: Args, ) -> StaticPayload<Call>

Call a Job in the service. The caller needs to be the owner of the service, or a permitted caller.

pub fn submit_result( &self, service_id: ServiceId, call_id: CallId, result: Result, ) -> StaticPayload<SubmitResult>

Submit the job result by using the service ID and call ID.

pub fn slash( &self, offender: Offender, service_id: ServiceId, percent: Percent, ) -> StaticPayload<Slash>

Slash an operator (offender) for a service id with a given percent of their exposed stake for that service.

The caller needs to be an authorized Slash Origin for this service. Note that this does not apply the slash directly, but instead schedules a deferred call to apply the slash by another entity.

pub fn dispute(&self, era: Era, index: Index) -> StaticPayload<Dispute>

Dispute an [UnappliedSlash] for a given era and index.

The caller needs to be an authorized Dispute Origin for the service in the [UnappliedSlash].

pub fn update_master_blueprint_service_manager( &self, address: Address, ) -> StaticPayload<UpdateMasterBlueprintServiceManager>