tangle_subxt::tangle_testnet_runtime::api::session

Module events

Modules

Structs

  • New session has happened. Note that the argument is the session index, not the block number as the type might suggest.