pub struct StorageApi;Implementations
sourceimpl StorageApi
impl StorageApi
sourcepub fn epoch_index(&self) -> StaticAddress<(), EpochIndex, Yes, Yes, ()>
pub fn epoch_index(&self) -> StaticAddress<(), EpochIndex, Yes, Yes, ()>
Current epoch index.
Current epoch authorities.
sourcepub fn genesis_slot(&self) -> StaticAddress<(), GenesisSlot, Yes, Yes, ()>
pub fn genesis_slot(&self) -> StaticAddress<(), GenesisSlot, Yes, Yes, ()>
The slot at which the first epoch actually started. This is 0 until the first block of the chain.
sourcepub fn current_slot(&self) -> StaticAddress<(), CurrentSlot, Yes, Yes, ()>
pub fn current_slot(&self) -> StaticAddress<(), CurrentSlot, Yes, Yes, ()>
Current slot number.
sourcepub fn randomness(&self) -> StaticAddress<(), Randomness, Yes, Yes, ()>
pub fn randomness(&self) -> StaticAddress<(), Randomness, Yes, Yes, ()>
The epoch randomness for the current epoch.
Security
This MUST NOT be used for gambling, as it can be influenced by a malicious validator in the short term. It MAY be used in many cryptographic protocols, however, so long as one remembers that this (like everything else on-chain) it is public. For example, it can be used where a number is needed that cannot have been chosen by an adversary, for purposes such as public-coin zero-knowledge proofs.
sourcepub fn pending_epoch_config_change(
&self,
) -> StaticAddress<(), PendingEpochConfigChange, Yes, (), ()>
pub fn pending_epoch_config_change( &self, ) -> StaticAddress<(), PendingEpochConfigChange, Yes, (), ()>
Pending epoch configuration change that will be applied when the next epoch is enacted.
sourcepub fn next_randomness(&self) -> StaticAddress<(), NextRandomness, Yes, Yes, ()>
pub fn next_randomness(&self) -> StaticAddress<(), NextRandomness, Yes, Yes, ()>
Next epoch randomness.
Next epoch authorities.
sourcepub fn segment_index(&self) -> StaticAddress<(), SegmentIndex, Yes, Yes, ()>
pub fn segment_index(&self) -> StaticAddress<(), SegmentIndex, Yes, Yes, ()>
Randomness under construction.
We make a trade-off between storage accesses and list length.
We store the under-construction randomness in segments of up to
UNDER_CONSTRUCTION_SEGMENT_LENGTH.
Once a segment reaches this length, we begin the next one.
We reset all segments and return to 0 at the beginning of every
epoch.
sourcepub fn under_construction_iter(
&self,
) -> StaticAddress<(), UnderConstruction, (), Yes, Yes>
pub fn under_construction_iter( &self, ) -> StaticAddress<(), UnderConstruction, (), Yes, Yes>
TWOX-NOTE: SegmentIndex is an increasing integer, so this is okay.
sourcepub fn under_construction(
&self,
_0: impl Borrow<Param0>,
) -> StaticAddress<StaticStorageKey<Param0>, UnderConstruction, Yes, Yes, ()>
pub fn under_construction( &self, _0: impl Borrow<Param0>, ) -> StaticAddress<StaticStorageKey<Param0>, UnderConstruction, Yes, Yes, ()>
TWOX-NOTE: SegmentIndex is an increasing integer, so this is okay.
sourcepub fn initialized(&self) -> StaticAddress<(), Initialized, Yes, (), ()>
pub fn initialized(&self) -> StaticAddress<(), Initialized, Yes, (), ()>
Temporary value (cleared at block finalization) which is Some
if per-block initialization has already been called for current block.
This field should always be populated during block processing unless secondary plain slots are enabled (which don’t contain a VRF output).
It is set in on_finalize, before it will contain the value from the last block.
sourcepub fn epoch_start(&self) -> StaticAddress<(), EpochStart, Yes, Yes, ()>
pub fn epoch_start(&self) -> StaticAddress<(), EpochStart, Yes, Yes, ()>
The block numbers when the last and current epoch have started, respectively N-1 and
N.
NOTE: We track this is in order to annotate the block number when a given pool of
entropy was fixed (i.e. it was known to chain observers). Since epochs are defined in
slots, which may be skipped, the block numbers may not line up with the slot numbers.
sourcepub fn lateness(&self) -> StaticAddress<(), Lateness, Yes, Yes, ()>
pub fn lateness(&self) -> StaticAddress<(), Lateness, Yes, Yes, ()>
How late the current block is compared to its parent.
This entry is populated as part of block execution and is cleaned up on block finalization. Querying this storage entry outside of block execution context should always yield zero.
sourcepub fn epoch_config(&self) -> StaticAddress<(), EpochConfig, Yes, (), ()>
pub fn epoch_config(&self) -> StaticAddress<(), EpochConfig, Yes, (), ()>
The configuration for the current epoch. Should never be None as it is initialized in
genesis.
sourcepub fn next_epoch_config(
&self,
) -> StaticAddress<(), NextEpochConfig, Yes, (), ()>
pub fn next_epoch_config( &self, ) -> StaticAddress<(), NextEpochConfig, Yes, (), ()>
The configuration for the next epoch, None if the config will not change
(you can fallback to EpochConfig instead in that case).
sourcepub fn skipped_epochs(&self) -> StaticAddress<(), SkippedEpochs, Yes, Yes, ()>
pub fn skipped_epochs(&self) -> StaticAddress<(), SkippedEpochs, Yes, Yes, ()>
A list of the last 100 skipped epochs and the corresponding session index when the epoch was skipped.
This is only used for validating equivocation proofs. An equivocation proof must contains a key-ownership proof for a given session, therefore we need a way to tie together sessions and epoch indices, i.e. we need to validate that a validator was the owner of a given key on a given session, and what the active epoch index was during that session.